==> thumbnail_creator-0.0.2.tar.gz: android/src/main/java/com/example/thumbnail_creator/ThumbnailCreatorPlugin.java <==
package com.example.thumbnail_creator;

import android.Manifest;
import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;
import android.os.Build;
import android.util.Log;

import java.io.ByteArrayOutputStream;
import java.io.File;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterPlugin */
public class ThumbnailCreatorPlugin implements MethodCallHandler {
  static Registrar registrar_global;
  static Result result_global;
  static MethodCall call_global;

  public static void registerWith(Registrar registrar) {
    registrar_global = registrar;
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "flutter_plugin");
    channel.setMethodCallHandler(new ThumbnailCreatorPlugin());
  }

  @TargetApi(Build.VERSION_CODES.M)
  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getThumbnail")) {
      result_global = result;
      call_global = call;

      String path = call_global.argument("path");

      File file = new File(path);

      if(file.exists()) {
        new LongOperation().execute();
      } else {
        result.error("File does not exist", "yeet", "yoot");
      }
    } else {
      result.notImplemented();
    }
  }

  public static byte[] decodeSampledBitmap(String path, int reqWidth, int reqHeight) {
    // First decode with inJustDecodeBounds=true to check dimensions
    final BitmapFactory.Options options = new BitmapFactory.Options();
    options.inJustDecodeBounds = true;
    BitmapFactory.decodeFile(path, options);

    // Calculate inSampleSize
    options.inSampleSize = calculateInSampleSize(options, reqWidth, reqHeight);

    // Decode bitmap with inSampleSize set
    options.inJustDecodeBounds = false;

    Bitmap bmp = BitmapFactory.decodeFile(path, options);

    ByteArrayOutputStream stream = new ByteArrayOutputStream();
    bmp.compress(Bitmap.CompressFormat.JPEG, 75, stream);

    byte[] byteArray = stream.toByteArray();
    bmp.recycle();

    return byteArray;
  }

  public static int calculateInSampleSize(BitmapFactory.Options options, int reqWidth, int reqHeight) {
    // Raw height and width of image
    final int height = options.outHeight;
    final int width = options.outWidth;
    int inSampleSize = 1;

    if (height > reqHeight || width > reqWidth) {

      final int halfHeight = height / 2;
      final int halfWidth = width / 2;

      // Calculate the largest inSampleSize value that is a power of 2 and keeps both
      // height and width larger than the requested height and width.
      while ((halfHeight / inSampleSize) >= reqHeight
              && (halfWidth / inSampleSize) >= reqWidth) {
        inSampleSize *= 2;
      }
    }

    return inSampleSize;
  }

  @TargetApi(Build.VERSION_CODES.CUPCAKE)
  private class LongOperation extends AsyncTask<String, Void, byte[]> {

    @Override
    protected byte[] doInBackground(String... params) {
      String path = call_global.argument("path");
      int reqWidth = call_global.argument("reqWidth");
      int reqHeight = call_global.argument("reqHeight");
      byte[] bytes = decodeSampledBitmap(path, reqWidth, reqHeight);

      Log.d("BYTE_LENGTH", String.valueOf(bytes.length));
      return bytes;
    }

    @Override
    protected void onPostExecute(byte[] result) {
      result_global.success(result);
    }

    @Override
    protected void onPreExecute() {}

    @Override
    protected void onProgressUpdate(Void... values) {}
  }
}

==> thumbnail_creator-0.0.3.tar.gz: android/src/main/java/com/example/thumbnail_creator/ThumbnailCreatorPlugin.java <==
package com.example.thumbnail_creator;

import android.Manifest;
import android.annotation.TargetApi;
import android.graphics.Bitmap;
import android.graphics.BitmapFactory;
import android.os.AsyncTask;
import android.os.Build;
import android.util.Log;

import java.io.ByteArrayOutputStream;
import java.io.File;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** FlutterPlugin */
public class ThumbnailCreatorPlugin implements MethodCallHandler {
  static Registrar registrar_global;
  static Result result_global;
  static MethodCall call_global;

  public static void registerWith(Registrar registrar) {
    registrar_global = registrar;
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "thumbnail_creator");
    channel.setMethodCallHandler(new ThumbnailCreatorPlugin());
  }

  @TargetApi(Build.VERSION_CODES.M)
  @Override
  public void onMethodCall(MethodCall call, Result result) {
    if (call.method.equals("getThumbnail")) {
      result_global = result;
      call_global = call;

      String path = call_global.argument("path");

      File file = new File(path);

      if(file.exists()) {
        new LongOperation().execute();
      } else {
        result.error("File does not exist", "yeet", "yoot");
      }
    } else {
      result.notImplemented();
    }
  }

  public static byte[] decodeSampledBitmap(String path, int reqWidth, int reqHeight) {
    // First decode with inJustDecodeBounds=true to check dimensions
    final BitmapFactory.Options options = new BitmapFactory.Options();
    options.inJustDecodeBounds = true;
    BitmapFactory.decodeFile(path, options);

    // Calculate inSampleSize
    options.inSampleSize = calculateInSampleSize(options, reqWidth, reqHeight);

    // Decode bitmap with inSampleSize set
    options.inJustDecodeBounds = false;

    Bitmap bmp = BitmapFactory.decodeFile(path, options);

    ByteArrayOutputStream stream = new ByteArrayOutputStream();
    bmp.compress(Bitmap.CompressFormat.JPEG, 75, stream);

    byte[] byteArray = stream.toByteArray();
    bmp.recycle();

    return byteArray;
  }

  public static int calculateInSampleSize(BitmapFactory.Options options, int reqWidth, int reqHeight) {
    // Raw height and width of image
    final int height = options.outHeight;
    final int width = options.outWidth;
    int inSampleSize = 1;

    if (height > reqHeight || width > reqWidth) {

      final int halfHeight = height / 2;
      final int halfWidth = width / 2;

      // Calculate the largest inSampleSize value that is a power of 2 and keeps both
      // height and width larger than the requested height and width.
      while ((halfHeight / inSampleSize) >= reqHeight
              && (halfWidth / inSampleSize) >= reqWidth) {
        inSampleSize *= 2;
      }
    }

    return inSampleSize;
  }

  @TargetApi(Build.VERSION_CODES.CUPCAKE)
  private class LongOperation extends AsyncTask<String, Void, byte[]> {

    @Override
    protected byte[] doInBackground(String... params) {
      String path = call_global.argument("path");
      int reqWidth = call_global.argument("reqWidth");
      int reqHeight = call_global.argument("reqHeight");
      byte[] bytes = decodeSampledBitmap(path, reqWidth, reqHeight);

      //Log.d("BYTE_LENGTH", String.valueOf(bytes.length));
      return bytes;
    }

    @Override
    protected void onPostExecute(byte[] result) {
      result_global.success(result);
    }

    @Override
    protected void onPreExecute() {}

    @Override
    protected void onProgressUpdate(Void... values) {}
  }
}
